@@ -1,8 +1,8 @@
-## PGLS.R (2012-02-09)
+## PGLS.R (2017-04-25)
 
 ##   Phylogenetic Generalized Least Squares
 
-## Copyright 2004 Julien Dutheil, and 2006-2012 Emmanuel Paradis
+## Copyright 2004 Julien Dutheil, and 2006-2017 Emmanuel Paradis
 
 ## This file is part of the R-package `ape'.
 ## See the file ../COPYING for licensing issues.
@@ -92,7 +92,6 @@ corMatrix.corBrownian <-
         stop("object has not been initialized.")
     tree <- attr(object, "tree")
     mat <- vcv.phylo(tree, corr = corr)
-    n <- dim(mat)[1]
     ## reorder matrix:
     index <- attr(object, "index")
     mat[index, index]
@@ -109,7 +108,6 @@ corMatrix.corMartins <-
     dist <- cophenetic.phylo(tree)
     mat <- exp(-object[1] * dist)
     if (corr) mat <- cov2cor(mat)
-    n <- dim(mat)[1]
     ## reorder matrix:
     index <- attr(object, "index")
     mat[index, index]
@@ -125,7 +123,6 @@ corMatrix.corGrafen <-
     tree <- compute.brlen(attr(object, "tree"),
                           method = "Grafen", power = exp(object[1]))
     mat <- vcv.phylo(tree, corr = corr)
-    n <- dim(mat)[1]
     ## reorder matrix:
     index <- attr(object, "index")
     mat[index, index]
@@ -170,9 +167,7 @@ coef.corGrafen <- function(object, unconstrained = TRUE, ...)
     aux
 }
 
-### removed node.sons() and node.leafnumber()  (2006-10-12)
-
-### changed by EP (2006-10-12):
+## changed by EP (2006-10-12):
 
 compute.brlen <- function(phy, method = "Grafen", power = 1, ...)
 {
@@ -191,9 +186,9 @@ compute.brlen <- function(phy, method = "Grafen", power = 1, ...)
     }
     if (is.character(method)) { # == "Grafen"
         tr <- reorder(phy, "postorder")
-        xx <- .C(node_depth, as.integer(Ntip), as.integer(Nnode),
+        xx <- .C(node_depth, as.integer(Ntip),
                  as.integer(tr$edge[, 1]), as.integer(tr$edge[, 2]),
-                 as.integer(Nedge), double(Ntip + Nnode), 1L)[[6]] - 1
+                 as.integer(Nedge), double(Ntip + Nnode), 1L)[[5]] - 1
         m <- Ntip - 1
         phy$edge.length <-
           (xx[phy$edge[, 1]]/m)^power - (xx[phy$edge[, 2]]/m)^power
